==> org.eclipse.smartmdsd.xtext.base.docuterminals.ui.source_1.0.0.202103091507.jar: org/eclipse/smartmdsd/xtext/base/docuterminals/ui/DocuTerminalsExecutableExtensionFactory.java <==
/********************************************************************************
 * Copyright (c) 2019 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * headed by Prof. Dr. Christian Schlegel
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 ********************************************************************************/
package org.eclipse.smartmdsd.xtext.base.docuterminals.ui;

import com.google.inject.Injector;
import org.eclipse.core.runtime.Platform;
import org.eclipse.smartmdsd.xtext.base.docuterminals.ui.internal.DocuterminalsActivator;
import org.eclipse.xtext.ui.guice.AbstractGuiceAwareExecutableExtensionFactory;
import org.osgi.framework.Bundle;

/**
 * This class was generated. Customizations should only happen in a newly
 * introduced subclass. 
 */
public class DocuTerminalsExecutableExtensionFactory extends AbstractGuiceAwareExecutableExtensionFactory {

	@Override
	protected Bundle getBundle() {
		return Platform.getBundle(DocuterminalsActivator.PLUGIN_ID);
	}
	
	@Override
	protected Injector getInjector() {
		DocuterminalsActivator activator = DocuterminalsActivator.getInstance();
		return activator != null ? activator.getInjector(DocuterminalsActivator.ORG_ECLIPSE_SMARTMDSD_XTEXT_BASE_DOCUTERMINALS_DOCUTERMINALS) : null;
	}

}

==> org.eclipse.smartmdsd.xtext.base.docuterminals.ui.source_1.0.0.202204040811.jar: org/eclipse/smartmdsd/xtext/base/docuterminals/ui/DocuTerminalsExecutableExtensionFactory.java <==
/********************************************************************************
 * Copyright (c) 2019 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * headed by Prof. Dr. Christian Schlegel
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 ********************************************************************************/
package org.eclipse.smartmdsd.xtext.base.docuterminals.ui;

import com.google.inject.Injector;
import org.eclipse.smartmdsd.xtext.base.docuterminals.ui.internal.DocuterminalsActivator;
import org.eclipse.xtext.ui.guice.AbstractGuiceAwareExecutableExtensionFactory;
import org.osgi.framework.Bundle;
import org.osgi.framework.FrameworkUtil;

/**
 * This class was generated. Customizations should only happen in a newly
 * introduced subclass. 
 */
public class DocuTerminalsExecutableExtensionFactory extends AbstractGuiceAwareExecutableExtensionFactory {

	@Override
	protected Bundle getBundle() {
		return FrameworkUtil.getBundle(DocuterminalsActivator.class);
	}
	
	@Override
	protected Injector getInjector() {
		DocuterminalsActivator activator = DocuterminalsActivator.getInstance();
		return activator != null ? activator.getInjector(DocuterminalsActivator.ORG_ECLIPSE_SMARTMDSD_XTEXT_BASE_DOCUTERMINALS_DOCUTERMINALS) : null;
	}

}
